@@ -1,6 +1,6 @@
 /* b-fro.c --- read-only file
 
-   Copyright (C) 2010-2020 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -304,7 +304,7 @@ fro_must_getbyte (int *c, struct fro *f)
 #endif
 
 void
-fro_trundling (bool sequential USED_IF_HAVE_MADVISE, struct fro *f)
+fro_trundling (USED_IF_HAVE_MADVISE bool sequential, struct fro *f)
 /* Advise the mmap machinery (if applicable) that access to ‘f’
    is sequential if ‘sequential’, otherwise normal.  */
 {
