@@ -1,6 +1,6 @@
 /* gnu-h-v.h --- GNUish --help and --version handling
 
-   Copyright (C) 2010-2015 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -23,7 +23,8 @@
 /* Clear ‘optind’ and ‘opterr’ then call ‘getopt_long’, arranging
    to do not permute ‘argv’.  Return what ‘getopt_long’ returns.  */
 extern int
-nice_getopt (int argc, char **argv, const struct option *longopts);
+nice_getopt (int argc, char **argv, const struct option *longopts)
+  ALL_NONNULL;
 
 #define DV_ONLY   0
 #define DV_WARN   1
@@ -40,7 +41,8 @@ nice_getopt (int argc, char **argv, const struct option *longopts);
    | DV_EXIT -- finish w/ ‘exit (EXIT_SUCCESS)’
    The default is 0.  */
 extern void
-display_version (struct program const *prog, int flags);
+display_version (struct program const *prog, int flags)
+  ALL_NONNULL;
 
 /* If ARGC is less than 2, do nothing.
    If ARGV[1] is "--version", use ‘display_version’ and exit successfully.
@@ -49,7 +51,8 @@ display_version (struct program const *prog, int flags);
    and exit successfully.  NAME is the value of ‘prog->name’,
    while HELP is the value of ‘prog->help’.  */
 extern void
-check_hv (int argc, char **argv, struct program const *prog);
+check_hv (int argc, char **argv, struct program const *prog)
+  ALL_NONNULL;
 
 /* Idioms.  */
 
