@@ -1,6 +1,6 @@
 /* Parse a string, returning a ‘struct partime’ that describes it.
 
-   Copyright (C) 2010-2015 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
    Copyright (C) 1993, 1994, 1995 Paul Eggert
 
    This file is part of GNU RCS.
@@ -232,7 +232,9 @@ parse_ranged (char const *s, int digits, int lo, int hi, int *res)
    the first character after the prefix, or 0 if it couldn't be parsed.  */
 {
   s = parse_fixed (s, digits, res);
-  return s && lo <= *res && *res <= hi ? s : NULL;
+  return s && lo <= *res && *res <= hi
+    ? s
+    : NULL;
 }
 
 static char const *
@@ -271,12 +273,13 @@ parse_decimal (char const *s, int digits, int lo, int hi,
   return NULL;
 }
 
-char const*
+char const *
 parzone (char const *s, long *zone)
-/* Parse an initial prefix of ‘s’; it must denote a time zone.  Set ‘*zone’
-   to the number of seconds east of GMT, or to ‘TM_LOCAL_ZONE’ if it is the
-   local time zone.  Return the first character after the prefix, or 0 if it
-   couldn't be parsed.  */
+/* Try to parse an initial prefix of ‘s’; it must denote a time zone.
+   If ‘s’ cannot be parsed, return NULL.  Otherwise, set ‘*zone’ to
+   the number of seconds east of GMT, or to ‘TM_LOCAL_ZONE’ if it is
+   the local time zone, and return a pointer to the first character
+   after the prefix.  */
 {
   char sign;
   int hh, mm, ss;
@@ -334,6 +337,7 @@ parzone (char const *s, long *zone)
         case '+':
           break;
         default:
+          *zone = z;
           return s;
         }
     }
