@@ -1,6 +1,6 @@
 /* Compare RCS revisions.
 
-   Copyright (C) 2010-2020 Thien-Thi Nguyen
+   Copyright (C) 2010-2022 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -394,7 +394,7 @@ rcsdiff_main (const char *cmd, int argc, char **argv)
         if (zonearg)
           *pp++ = zonearg;
         *pp++ = REPO (filename);
-        *pp = '\0';
+        *pp = NULL;
 
         diffp = diffpend;
         if (OPEN_O_BINARY
